/* ---------------------------------------------------------
   Natural convection of air in a square cavity of dimensions
   [0,1]x[0,1]
   System of eq: Incompressible unsteady Navier-Stokes-Boussinesq
   Boyancy force: fB = Ra/(Rey^2 Pr) T
   Continuation on Temperature

               *** PHYSICAL PARAMETERS***
   --------------------------------------------------------*/

// FES and choice of the scaling -----------------
macro typeT P1// P1 or P2
IFMACRO(spaceconvergence)
   macro scalAdim()1//
   real Ra=1e4;
ENDIFMACRO
IFMACRO(timeconvergence)
   macro scalAdim()3//
   real Ra=1e6;
ENDIFMACRO

// Dimension of the cavity --------------------------------
real xl=0,xr=1.,yl=0,yr=1.; // Square dimension [xl,xr]x[yl,yr]
int nbseg=100;
mesh Th=square(nbseg,nbseg);

// Dimensionless numbers ----------------------------------
real Pr=.71;
real dt=.1;

real c1=1./dt,c2=-1./dt,c3=0.;

real Rey, IRe, IRa, IPr, Uscal;
real t,dtorig=dt,dtref=dt,tmax=pi;

IFMACRO(scalAdim,1)
   Rey=1;
   Uscal = Pr/sqrt(Ra);
ENDIFMACRO

IFMACRO(scalAdim,2)
   Rey=1./Pr;
   Uscal = 1.;
ENDIFMACRO

IFMACRO(scalAdim,3)
   Rey=sqrt(Ra/Pr);
   Uscal = sqrt(Pr);
ENDIFMACRO

// Dimensionless Temp ----------------------------------
real Thot=0.5, Tcold=-.5, Tin=.8;
int nbcontT=3; // nb iteration for temperature continuation
real Thotf = Thot,Tcoldf = Tcold,Tinf=Tin;// final Thot, Tcold and Tin
real Tinit = (Tcold+Thot)/2.;

// Boundary conditions ---------------------------------
int cold=1,hot=3;// label of the boundary
int[int] wall1 = [1,2,4],wall2 = [1,2,3,4];

macro convergencerhs true//
IFMACRO(spaceconvergence)
   macro bcu1()on(wall1,uw1=0)+on(hot,uw1=ubnd)//
   macro bcu2()on(wall2,uw2=0)//
   macro bcT()on(cold,Tw=Tcold)+on(hot,Tw=Thot)//
ENDIFMACRO
IFMACRO(timeconvergence)
   macro bcu1()on(wall2,uw1=u1ex(t+dt))//
   macro bcu2()on(wall2,uw2=u2ex(t+dt))//
   macro bcT()on(wall2,Tw=Tex(t+dt))//
ENDIFMACRO

IRe = 1./Rey;
IRa = Ra/(Rey*Rey*Pr); IPr = 1./(Rey*Pr);

// Boussinesq forces ----------------------------------------
/*
   For air: fB = Ra/(Re^2 Pr)*T = IRa * T
*/
macro fB(T)  (IRa*T)//
macro dfB(T) (IRa)//