/* ---------------------------------------------------------
   Natural convection of air in a square cavity of dimensions
   [0,1]x[0,1] with a square heated obstacle
   System of eq: Incompressible unsteady Navier-Stokes-Boussinesq
   Boyancy force: fB = Ra/(Rey^2 Pr) T

               *** PHYSICAL PARAMETERS***
   --------------------------------------------------------*/

// FES and choice of the scaling -----------------
macro typeT P2// P1 or P2
macro scalAdim()1// 1,2 or 3

// Dimension of the cavity --------------------------------
real xl=0,xr=1.,yl=0,yr=1.; // Square dimension [xl,xr]x[yl,yr]
int nbseg = 40;
int obst=5;
real xlB=0.35*xr, xrB=0.65*xr;
real ylB=0.35*yr, yrB=0.65*yr;
mesh Th = square(nbseg,nbseg,[M2zonesCarre(x,xl,xr,xlB,xrB),M2zonesCarre(y,yl,yr,ylB,yrB)]);
Th = trunc(Th,((x>xrB|x<xlB) |(y>yrB|y<ylB)),label=obst);

// Dimensionless numbers ----------------------------------
real Pr=0.71,Ra=1e6;
real dt=1.,dtmax=10.;

real Rey, IRe, IRa, IPr, Uscal, tscal;
real t,dtorig=dt;
int dtadapt=2,dtstep=10;

IFMACRO(scalAdim,1)
   Rey=1;
   Uscal = Pr/sqrt(Ra);
   tscal = 1;
ENDIFMACRO

IFMACRO(scalAdim,2)
   Rey=1./Pr;
   Uscal = 1.;
   tscal=1./Pr;
ENDIFMACRO

IFMACRO(scalAdim,3)
   Rey=sqrt(Ra/Pr);
   Uscal = sqrt(Pr);
   tscal = sqrt(Ra/Pr);
ENDIFMACRO

dt *= tscal/1.e3;
dtmax *= tscal;
dtorig = dt;
real c1=1./dt,c2=-1./dt,c3=0.;

// Dimensionless Temp ----------------------------------
real Thot=0.5, Tcold=-.5, Tin=.8;
int iterCT,nbcontT=6; // nb iteration for temperature continuation
real Thotf = Thot,Tcoldf = Tcold,Tinf=Tin;// final Thot, Tcold and Tin
real Tinit = (Tcold+Thot)/2.;

// Boundary conditions ---------------------------------
int cold=2,hot=4;// label of the boundary
int[int] wall = [1,2,3,4,5];

macro bcu1()on(wall,uw1=0)//
macro bcu2()on(wall,uw2=0)//
macro bcT()on(cold,Tw=Tcold)+on(hot,Tw=Thot)+on(obst,Tw=Tin)//

IRe = 1./Rey;
IRa = Ra/(Rey*Rey*Pr); IPr = 1./(Rey*Pr);

// Boussinesq forces ----------------------------------------
/*
   For air: fB = Ra/(Re^2 Pr)*T = IRa * T
*/
macro fB(T)  (IRa*T)//
macro dfB(T) (IRa)//