/* ---------------------------------------------------------
   Melting of cylindrical PCM with inner heated tube
   [0,1]x[0,1]
   Case #3: Luo et. al (2015)
   System of eq: Incompressible Navier-Stokes-Boussinesq +
                  Enthalpy method in Energy eq
   Boyancy force: fB = Ra/(Rey^2 Pr) T
   Continuation on Temperature for transient regime

               *** PHYSICAL PARAMETERS***
   --------------------------------------------------------*/

// FES and choice of the scaling -----------------
macro typeT P2// P1 or P2
macro scalAdim()1// 1,2 or 3

// Dimension of the cavity --------------------------------
int Ntubes=1;// 1, 4, 9 Tubes
int nbseg = 80;
mesh Th;
real r1=1, r2=r1/4., r3=r1/8, r4=r1/12, r5=sqrt(2)/2.*r1, r6=sqrt(2)/4.*r1; // Tubes dimensions
border gamma1(t=r1,r2){label=2;x=0;y=t;}
border gamma2(t=-r2,-r1){label=2;x=0;y=t;}
border gamma3(t=r1,5.*r3){label=2;x=0;y=t;}
border gamma4(t=3.*r1/8.,-3.*r1/8.){label=2;x=0;y=t;}
border gamma5(t=-5.*r3,-r1){label=2;x=0;y=t;}
border gamma6(t=r1,r5+r4){label=2;x=0;y=t;}
border gamma7(t=r5-r4,r4){label=2;x=0;y=t;}
border gamma8(t=-r4,-r5+r4){label=2;x=0;y=t;}
border gamma9(t=-r5-r4,-r1){label=2;x=0;y=t;}
border circleO(t=-pi/2,pi/2){label=1;x=r1*cos(t); y=r1*sin(t);}
border circle1(t=pi/2,-pi/2){label=3;x=r2*cos(t); y=r2*sin(t);}
border circle2(t=pi/2,-pi/2){label=3;x=r3*cos(t); y=r1/2.+r3*sin(t);}
border circle3(t=0,-2*pi){label=3;x=r1/2.+r3*cos(t); y=r3*sin(t);}
border circle4(t=pi/2,-pi/2){label=3;x=r3*cos(t); y=-r1/2.+r3*sin(t);}
border circle5(t=pi/2,-pi/2){label=3;x=r4*cos(t); y=r5+r4*sin(t);}
border circle6(t=pi/2,-pi/2){label=3;x=r4*cos(t); y=r4*sin(t);}
border circle7(t=pi/2,-pi/2){label=3;x=r4*cos(t); y=-r5+r4*sin(t);}
border circle8(t=0,-2*pi){label=3;x=r5+r4*cos(t); y=r4*sin(t);}
border circle9(t=0,-2*pi){label=3;x=r6+r4*cos(t); y=r6+r4*sin(t);}
border circle10(t=0,-2*pi){label=3;x=r6+r4*cos(t); y=-r6+r4*sin(t);}
if(Ntubes==1)
   Th=buildmesh(gamma2(nbseg*(r1-r2))+circleO(nbseg*pi*r1)+gamma1(nbseg*(r1-r2))+circle1(nbseg*pi*r2));
if(Ntubes==4)
   Th=buildmesh(circleO(nbseg*pi*r1)+gamma3(nbseg*(r1-5*r3))+circle2(nbseg*pi*r3)+gamma4(nbseg*6*r3)+circle4(nbseg*pi*r3)+gamma5(nbseg*(r1-5*r3))+circle3(2*nbseg*pi*r3));
if(Ntubes==9)
   Th=buildmesh(circleO(nbseg*pi*r1)+gamma6(nbseg*(r1-r5-r4))+circle5(nbseg*pi*r4)+gamma7(nbseg*(r5-2.*r4))+circle6(nbseg*pi*r4)+gamma8(nbseg*(r5-2.*r4))+circle7(nbseg*pi*r4)+gamma9(nbseg*(r1-r5-r4))+circle8(nbseg*2*pi*r4)+circle9(nbseg*2.*pi*r4)+circle10(nbseg*2.*pi*r4));

// Dimensionless numbers ----------------------------------
real Pr=.2,Ra=5.e4,Ste=0.02;
real dt=1.e-3,dtmax=1.e-2,tmax;

real Rey, IRe, IRa, IPr, Uscal, tscal;
real t,dtorig=dt;
int dtadapt=1,dtstep=10;
int iterCT,nbcontT1=0,nbcontT2=5; // nb iteration for temperature continuation

// time save for Tecplot layout of the paper --------------
int nts;
real epsts=1e-10;
real[int] timesave;
if(Ntubes==1){
   timesave=[2.501];
   tmax=4.;
}
if(Ntubes==4){
   timesave=[1.001];
   tmax=1.5;
}
if(Ntubes==9){
   timesave=[.401];
   tmax=.99;
}

IFMACRO(scalAdim,1)
   Rey=1;
   Uscal = Pr/sqrt(Ra);
   tscal = 1;
ENDIFMACRO

IFMACRO(scalAdim,2)
   Rey=1./Pr;
   Uscal = 1.;
   tscal=1./Pr;
ENDIFMACRO

IFMACRO(scalAdim,3)
   Rey=sqrt(Ra/Pr);
   Uscal = sqrt(Pr);
   tscal = sqrt(Ra/Pr);
ENDIFMACRO

timesave *= tscal;
dt *= tscal;
dtmax *= tscal;
tmax *= tscal;
dtorig = dt;
real c1=1./dt,c2=-1./dt,c3=0.;

// Dimensionless Temp ----------------------------------
real Tf=0;// temperature of fusion
real epsi=1.e-2;// width of the mushy region
real Thot = 1., Tcold = -.01, Tin = 1.;
real Thotf = Thot,Tcoldf = Tcold, Tinf = Tin;// final Thot, Tcold and Tin
real Tinit=Tcold;

// Boundary conditions ---------------------------------
int hot=3;// label of the boundary
int[int] wall = [1,2,3];

macro bcu1()on(wall,uw1=0)//
macro bcu2()on(1,3,uw2=0)//
macro bcT()on(hot,Tw=Thot)//

IRe = 1./Rey;
IRa = Ra/(Rey*Rey*Pr); IPr = 1./(Rey*Pr);

// Source term (latent heat) ---------------------------
real Enths=0,Enthl=1./Ste;
real Enthas = 1 ;
real EnthRs = epsi, EnthTs = Tf+epsi;

// Carman-Kozeny ---------------------------------------
real CCK = 1e6 , bmushy = 1e-7;
real CKs = 0. , CKl = 1.;
real CKas = 1 ;
real CKRs = epsi , CKTs = Tf+epsi ;

// Boussinesq forces ----------------------------------------
/*
   For PCM: fB = Ra/(Re^2 Pr)*T = IRa * T
*/
macro fB(T)  (IRa*T)//
macro dfB(T) (IRa)//