/* ---------------------------------------------------------
   Solid crust formation within irregular cavity.
   Case #5: Nourgaliev(2016)
   System of eq: Incompressible Navier-Stokes-Boussinesq +
                  Enthalpy method in Energy eq
   Boyancy force: fB = Ra/(Rey^2 Pr) T
   Continuation on Temperature for transient regime

               *** PHYSICAL PARAMETERS***
   --------------------------------------------------------*/

// FES and choice of the scaling -----------------
macro typeT P2// P1 or P2
macro scalAdim()3// 1,2 or 3

// Dimension of the cavity --------------------------------
int nbseg = 20;
real alpha = 20.*pi/180.;
real betha = 20.*pi/180.;
real oed = tan(alpha)/tan(betha);
real xM = (1.+0.5*tan(alpha))/(1-oed*tan(alpha)*tan(alpha));
real yM = 0.5 + (1+0.5*tan(alpha))/(1-oed*tan(alpha)*tan(alpha))*oed*tan(alpha);
macro f1(x) ((yM - 0.5)*x/xM + 0.5)//
macro f2(x) (yM/(xM-1)*(x-1))//
real yM1 = f1(-1);
real xM2 = 0.5*(1-xM)/yM+1;
real H = 0.5 + yM1 ;// Height
real L = 1. + xM2 ; // Length
real Tr1 = sqrt(pow(yM-yM1,2)+pow(1+xM,2));  // Gamma2
real Tr2 = sqrt(pow(xM-xM2,2)+pow(0.5+yM,2));// Gamma1
border Gamma1(t=-1,xM2){x=t;y=-0.5;label=1;};
border Gamma2(t=xM2,xM){x=t;y=f2(x);label=2;};
border Gamma3(t=xM,-1){x=t;y=f1(x);label=3;};
border Gamma4(t=yM1,-0.5){x=-1;y=t;label=4;};
mesh Th = buildmesh(Gamma1(nbseg*L/H)+Gamma2(nbseg*Tr2/H)+
                    Gamma3(nbseg*Tr1/H)+Gamma4(nbseg));

// Dimensionless numbers ----------------------------------
real Pr=.1,Ra=1.e6,Ste=4.854;
real dt=1.e-3,dtmax=1.,tmax=30.33;

real Rey, IRe, IRa, IPr, Uscal, tscal;
real t,dtorig=dt;
int dtadapt=30,dtstep=10;
int iterCT,nbcontT1=4,nbcontT2=0; // nb iteration for temperature continuation

// time save for Tecplot layout of the paper --------------
int nts;
real epsts=1e-10;
real[int] timesave=[30.33];

IFMACRO(scalAdim,1)
   Rey=1;
   Uscal = Pr/sqrt(Ra);
   tscal = 1;
ENDIFMACRO

IFMACRO(scalAdim,2)
   Rey=1./Pr;
   Uscal = 1.;
   tscal=1./Pr;
ENDIFMACRO

IFMACRO(scalAdim,3)
   Rey=sqrt(Ra/Pr);
   Uscal = sqrt(Pr);
   tscal = sqrt(Ra/Pr);
ENDIFMACRO

timesave *= tscal;
dt *= tscal;
dtmax *= tscal;
tmax *= tscal;
dtorig = dt;
real c1=1./dt,c2=-1./dt,c3=0.;

// Dimensionless Temp ----------------------------------
real epsi=1.e-2;// width of the mushy region
real Tf=1.41;// temperature of fusion
real Thot = 2., Tcold = Tf, Tin = 1.;
real Thotf = Thot,Tcoldf = Tcold,Tinf=Tin;// final Thot, Tcold and Tin
real Tinit = (Tcold+Thot)/2.;
real TcoldFreeze=1.;

// Boundary conditions ---------------------------------
int cold=4,hot=2;// label of the boundary
int[int] wall = [1,2,3,4];

macro bcu1()on(wall,uw1=0)//
macro bcu2()on(wall,uw2=0)//
macro bcT()on(cold,Tw=Tcold)+on(hot,Tw=Thot)//

IRe = 1./Rey;
IRa = Ra/(Rey*Rey*Pr); IPr = 1./(Rey*Pr);

// Source term (latent heat) ---------------------------
real Enths=0,Enthl=1./Ste;
real Enthas = 1 ;
real EnthRs = epsi, EnthTs = Tf+epsi;

// Carman-Kozeny ---------------------------------------
real CCK = 1e6 , bmushy = 1e-7;
real CKs = 0. , CKl = 1.;
real CKas = 1 ;
real CKRs = epsi , CKTs = Tf+epsi ;

// Boussinesq forces ----------------------------------------
/*
   For PCM: fB = Ra/(Re^2 Pr)*T = IRa * T
*/
macro fB(T)  (IRa*T)//
macro dfB(T) (IRa)//